@@ -26,6 +26,7 @@
 #' @template field_label
 #' @template field_man
 #'
+#' @template param_id
 #' @template param_param_set
 #' @template param_label
 #' @template param_man
@@ -34,17 +35,20 @@
 #' @export
 Terminator = R6Class("Terminator",
   public = list(
+    #' @template field_id
+    id = NULL,
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     #'
     #' @param properties (`character()`)\cr
     #'   Set of properties of the terminator.
-    #'   Must be a subset of [`mlr_reflections$terminator_properties`][mlr3::mlr_reflections].
+    #'   Must be a subset of [`bbotk_reflections$terminator_properties`][bbotk_reflections].
     #'
     #' @param unit (`character()`)\cr
     #'   Unit of steps.
-    initialize = function(param_set = ps(), properties = character(), unit = "percent", label = NA_character_, man = NA_character_) {
+    initialize = function(id, param_set = ps(), properties = character(), unit = "percent", label = NA_character_, man = NA_character_) {
+      self$id = assert_string(id, min.chars = 1L)
       private$.param_set = assert_param_set(param_set)
       private$.properties = assert_subset(properties, bbotk_reflections$terminator_properties)
       private$.unit = assert_string(unit)
@@ -110,7 +114,7 @@ Terminator = R6Class("Terminator",
 
     #' @field properties (`character()`)\cr
     #'   Set of properties of the terminator.
-    #'   Must be a subset of [`mlr_reflections$terminator_properties`][mlr3::mlr_reflections].
+    #'   Must be a subset of [`bbotk_reflections$terminator_properties`][bbotk_reflections].
     properties = function(rhs) {
       if (!missing(rhs) && !identical(rhs, private$.properties)) {
         stop("$properties is read-only.")
