@@ -40,3 +40,8 @@ test_that("TerminatorStagnationBatch works with empty archive", {
   archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
 })
+
+test_that("man exists", {
+  terminator = trm("stagnation_batch")
+  expect_man_exists(terminator$man)
+})
